@@ -1,16 +1,16 @@
 //! # edt
 //!
-//! An implementation of 2D EDT ([Euclidian distance transform](https://en.wikipedia.org/wiki/Distance_transform)) with Saito's algorithm in pure Rust
+//! An implementation of 2D EDT ([Euclidean distance transform](https://en.wikipedia.org/wiki/Distance_transform)) with Saito's algorithm in pure Rust
 //!
 //! There are also [other](https://crates.io/crates/distance-transform)
 //! [crates](https://crates.io/crates/dt) that implements EDT,
 //! but I would like to reinvent a wheel that has these advantages:
-//! 
+//!
 //! * No dependencies (except example codes)
 //! * Intuitive to use (accepts a numerical slice and a shape)
-//! 
+//!
 //! Performance was not the priority, but I would like to explore more optimizations.
-//! 
+//!
 //! EDT is the basis of many algorithms, but it is hard to find in a general purpose image processing library,
 //! probably because the algorithm is not trivial to implement efficiently.
 //! This crate provides an implementation of EDT in fairly efficient algorithm presented in the literature.
@@ -25,7 +25,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! edt = "0.1.0"
+//! edt = "0.2.0"
 //! ```
 //!
 //! Prepare a binary image as a flattened vec.
@@ -60,7 +60,7 @@
 //! ```
 //!
 //! Save to a file if you want.
-//! The code below normalizes the value with maximum value to 8 bytes grayscale image.
+//! The code below normalizes the value with maximum value to 8 bits grayscale image.
 //!
 //! ```rust
 //! # use edt::edt;
@@ -103,24 +103,37 @@
 mod primitive_impl;
 
 /// A trait for types that can be interpreted as a bool.
-/// 
+///
 /// Primitive numerical types (integers and floats) implement this trait,
 /// so you don't have to implement this by yourself.
 /// However, you could implement it for your own custom type, if you want.
-/// 
+///
 /// We don't use [num](https://crates.io/crates/num) crate because it is overkill for our purposes.
 pub trait BoolLike {
     fn as_bool(&self) -> bool;
 }
 
 /// Produce an EDT from binary image.
-/// 
+///
 /// The returned vec has the same size as the input slice, containing
 /// computed EDT.
-/// 
+///
 /// It assumes zero pixels are obstacles. If you want to invert the logic,
 /// put `true` to the third argument.
 pub fn edt<T: BoolLike>(map: &[T], shape: (usize, usize), invert: bool) -> Vec<f64> {
+    let mut ret = edt_sq(map, shape, invert);
+    for pixel in &mut ret {
+        *pixel = pixel.sqrt();
+    }
+    ret
+}
+
+/// Squared EDT of a given image.
+/// 
+/// The interface is equivalent to [`edt`], but it returns squared EDT.
+///
+/// It is more efficient if you only need squared edt, because you wouldn't need to compute square root.
+pub fn edt_sq<T: BoolLike>(map: &[T], shape: (usize, usize), invert: bool) -> Vec<f64> {
     let horz_edt = horizontal_edt(map, shape, invert);
 
     let vertical_scan = |x, y| {
@@ -128,7 +141,11 @@ pub fn edt<T: BoolLike>(map: &[T], shape: (usize, usize), invert: bool) -> Vec<f
             let horz_val: f64 = horz_edt[x + y2 * shape.0];
             (y2 as f64 - y as f64).powf(2.) + horz_val.powf(2.)
         });
-        total_edt.reduce(f64::min).unwrap()
+        total_edt
+            .reduce(f64::min)
+            .unwrap()
+            .min((y as f64).powf(2.))
+            .min(((shape.1 - y) as f64).powf(2.))
     };
 
     let mut ret = vec![0.; shape.0 * shape.1];
@@ -183,8 +200,8 @@ mod test {
             "0000000000",
             "0001111000",
             "0011111110",
+            "0011111100",
             "0001111000",
-            "0000110000",
         ];
         let map = flatten(
             str_map
@@ -243,8 +260,8 @@ mod test {
             "0000000000",
             "0001221000",
             "0012343210",
+            "0012332100",
             "0001221000",
-            "0000110000",
         ];
         print_2d(&reshape(
             &horizontal_edt(&map, (map.len() / str_edt.len(), str_edt.len()), false),
@@ -263,11 +280,11 @@ mod test {
             "0000000000",
             "0001111000",
             "0012442110",
-            "0001221000",
-            "0000110000",
+            "0012442100",
+            "0001111000",
         ];
         let shape = (map.len() / str_edt.len(), str_edt.len());
-        let edt = edt(&map, shape, false);
+        let edt = edt_sq(&map, shape, false);
         eprintln!("edt({:?}):", shape);
         print_2d(&reshape(&edt, shape));
         assert_eq!(edt, parse_edt_str(&str_edt));
